#!/usr/bin/env node
/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2016, 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/
// Node module: apiconnect-cli-policies

var g = require('strong-globalize')();

module.exports = {
  name: 'spaces',
  version: require('../package.json').version,
  path: __filename,
  isBuiltin: true,
  topics: getTopics,
};

function getTopics() {
  return [ {
    name: 'spaces',
    commands: [
      {
        command: 'list',
        aliases: [ 'spaces' ],
        loginRequired: true,
        helpInfo: g.f('apic_spaces_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').spacesList(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'get <name>',
        loginRequired: true,
        helpInfo: g.f('apic_spaces_get_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').spacesGet(name, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'create <displayName>',
        loginRequired: true,
        helpInfo: g.f('apic_spaces_create_help.txt'),
        action: function(displayName, opts) {
          return require('./plugin-impl').spacesCreate(displayName, opts);
        },
        options: [
          { name: 'name' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'delete <name>',
        loginRequired: true,
        helpInfo: g.f('apic_spaces_delete_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').spacesDelete(name, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'set <name>',
        loginRequired: true,
        helpInfo: g.f('apic_spaces_set_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').spacesSet(name, opts);
        },
        options: [
          { name: 'name' },
          { name: 'display-name' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
    ],
  },
  ];
};

